"""Version information."""
__title__ = "soh"
__description__ = "Sleight of hand (soh) CLI tool."
__url__ = "https://github.com/crflynn/soh"
__version__ = "0.1.0"
__author__ = "Christopher Flynn"
__author_email__ = "crf204@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2019"
__docs_copyright__ = "2019"
